summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_setup_pbuilder.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-09-22 18:44:15 +0200
committerHolger Levsen <holger@layer-acht.org>2015-09-22 18:44:15 +0200
commit03d5d90480a80ed300a7b9a2779474de4cbc10d3 (patch)
tree9d00a035c4f3ea530576ab0b47e8317126fabe96 /bin/reproducible_setup_pbuilder.sh
parentcf01779811629bb202cc45cea3bdcc4bac2608bc (diff)
downloadjenkins.debian.net-03d5d90480a80ed300a7b9a2779474de4cbc10d3.tar.xz
reproducible: create stamp file a bit in the past so that the next run in <24h thinks its older than 24h
Diffstat (limited to 'bin/reproducible_setup_pbuilder.sh')
-rwxr-xr-xbin/reproducible_setup_pbuilder.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_setup_pbuilder.sh b/bin/reproducible_setup_pbuilder.sh
index 90427db6..0fddb1de 100755
--- a/bin/reproducible_setup_pbuilder.sh
+++ b/bin/reproducible_setup_pbuilder.sh
@@ -108,8 +108,8 @@ setup_pbuilder() {
|| ( echo ; echo "Package ${PKG} is not installed at all or probably rather not in our version, so removing the chroot and exiting now." ; sudo rm -v /var/cache/pbuilder/${NAME}-new.tgz ; rm $TMPFILE $LOG ; exit 1 )
done
sudo mv /var/cache/pbuilder/${NAME}-new.tgz /var/cache/pbuilder/${NAME}.tgz
- # create stamp file to record initial creation date
- touch /var/log/jenkins/${NAME}.tgz.stamp
+ # create stamp file to record initial creation date minus some hours so the file will be older than 24h when checked in <24h...
+ touch -d "$(date -u -d '6 hours ago' '+%Y-%m-%d %H:%M')" /var/log/jenkins/${NAME}.tgz.stamp
rm ${TMPFILE} ${LOG}
}